@@ -1,23 +1,23 @@
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferCloseLevel ( hlevelhandle : super:: SAFER_LEVEL_HANDLE ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferCloseLevel ( hlevelhandle : super:: SAFER_LEVEL_HANDLE ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferComputeTokenFromLevel ( levelhandle : super:: SAFER_LEVEL_HANDLE , inaccesstoken : super::super::Foundation:: HANDLE , outaccesstoken : *mut super::super::Foundation:: HANDLE , dwflags : SAFER_COMPUTE_TOKEN_FROM_LEVEL_FLAGS , lpreserved : *mut ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferComputeTokenFromLevel ( levelhandle : super:: SAFER_LEVEL_HANDLE , inaccesstoken : super::super::Foundation:: HANDLE , outaccesstoken : *mut super::super::Foundation:: HANDLE , dwflags : SAFER_COMPUTE_TOKEN_FROM_LEVEL_FLAGS , lpreserved : *mut ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferCreateLevel ( dwscopeid : u32 , dwlevelid : u32 , openflags : u32 , plevelhandle : *mut super:: SAFER_LEVEL_HANDLE , lpreserved : *mut ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferCreateLevel ( dwscopeid : u32 , dwlevelid : u32 , openflags : u32 , plevelhandle : *mut super:: SAFER_LEVEL_HANDLE , lpreserved : *const ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferGetLevelInformation ( levelhandle : super:: SAFER_LEVEL_HANDLE , dwinfotype : SAFER_OBJECT_INFO_CLASS , lpquerybuffer : *mut ::core::ffi::c_void , dwinbuffersize : u32 , lpdwoutbuffersize : *mut u32 ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferGetLevelInformation ( levelhandle : super:: SAFER_LEVEL_HANDLE , dwinfotype : SAFER_OBJECT_INFO_CLASS , lpquerybuffer : *mut ::core::ffi::c_void , dwinbuffersize : u32 , lpdwoutbuffersize : *mut u32 ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferGetPolicyInformation ( dwscopeid : u32 , saferpolicyinfoclass : SAFER_POLICY_INFO_CLASS , infobuffersize : u32 , infobuffer : *mut ::core::ffi::c_void , infobufferretsize : *mut u32 , lpreserved : *mut ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferGetPolicyInformation ( dwscopeid : u32 , saferpolicyinfoclass : SAFER_POLICY_INFO_CLASS , infobuffersize : u32 , infobuffer : *mut ::core::ffi::c_void , infobufferretsize : *mut u32 , lpreserved : *const ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferIdentifyLevel ( dwnumproperties : u32 , pcodeproperties : *const SAFER_CODE_PROPERTIES_V2 , plevelhandle : *mut super:: SAFER_LEVEL_HANDLE , lpreserved : *const ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferIdentifyLevel ( dwnumproperties : u32 , pcodeproperties : *const SAFER_CODE_PROPERTIES_V2 , plevelhandle : *mut super:: SAFER_LEVEL_HANDLE , lpreserved : *const ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferRecordEventLogEntry ( hlevel : super:: SAFER_LEVEL_HANDLE , sztargetpath : :: windows_sys::core::PCWSTR , lpreserved : *mut ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferRecordEventLogEntry ( hlevel : super:: SAFER_LEVEL_HANDLE , sztargetpath : ::windows_sys::core::PCWSTR , lpreserved : *const ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferSetLevelInformation ( levelhandle : super:: SAFER_LEVEL_HANDLE , dwinfotype : SAFER_OBJECT_INFO_CLASS , lpquerybuffer : *const ::core::ffi::c_void , dwinbuffersize : u32 ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferSetLevelInformation ( levelhandle : super:: SAFER_LEVEL_HANDLE , dwinfotype : SAFER_OBJECT_INFO_CLASS , lpquerybuffer : *const ::core::ffi::c_void , dwinbuffersize : u32 ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferSetPolicyInformation ( dwscopeid : u32 , saferpolicyinfoclass : SAFER_POLICY_INFO_CLASS , infobuffersize : u32 , infobuffer : *const ::core::ffi::c_void , lpreserved : *mut ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferSetPolicyInformation ( dwscopeid : u32 , saferpolicyinfoclass : SAFER_POLICY_INFO_CLASS , infobuffersize : u32 , infobuffer : *const ::core::ffi::c_void , lpreserved : *const ::core::ffi::c_void ) -> super::super::Foundation:: BOOL );
 #[cfg(feature = "Win32_Foundation")]
-::windows_sys::core::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferiIsExecutableFileType ( szfullpathname : :: windows_sys::core::PCWSTR , bfromshellexecute : super::super::Foundation:: BOOLEAN ) -> super::super::Foundation:: BOOL );
+::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_Security_AppLocker\"`, `\"Win32_Foundation\"`*"] fn SaferiIsExecutableFileType ( szfullpathname : ::windows_sys::core::PCWSTR , bfromshellexecute : super::super::Foundation:: BOOLEAN ) -> super::super::Foundation:: BOOL );
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
 pub const SAFER_CRITERIA_APPX_PACKAGE: u32 = 32u32;
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
@@ -79,27 +79,27 @@ pub const SAFER_SCOPEID_MACHINE: u32 = 1u32;
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
 pub const SAFER_SCOPEID_USER: u32 = 2u32;
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_APPX: ::windows_sys::core::PCWSTR = ::windows_sys::w!("APPX");
+pub const SRP_POLICY_APPX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APPX");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_DLL: ::windows_sys::core::PCWSTR = ::windows_sys::w!("DLL");
+pub const SRP_POLICY_DLL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DLL");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_EXE: ::windows_sys::core::PCWSTR = ::windows_sys::w!("EXE");
+pub const SRP_POLICY_EXE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EXE");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_MANAGEDINSTALLER: ::windows_sys::core::PCWSTR = ::windows_sys::w!("MANAGEDINSTALLER");
+pub const SRP_POLICY_MANAGEDINSTALLER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MANAGEDINSTALLER");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_MSI: ::windows_sys::core::PCWSTR = ::windows_sys::w!("MSI");
+pub const SRP_POLICY_MSI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MSI");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_NOV2: ::windows_sys::core::PCWSTR = ::windows_sys::w!("IGNORESRPV2");
+pub const SRP_POLICY_NOV2: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IGNORESRPV2");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_SCRIPT: ::windows_sys::core::PCWSTR = ::windows_sys::w!("SCRIPT");
+pub const SRP_POLICY_SCRIPT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SCRIPT");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_SHELL: ::windows_sys::core::PCWSTR = ::windows_sys::w!("SHELL");
+pub const SRP_POLICY_SHELL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SHELL");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_WLDPCONFIGCI: ::windows_sys::core::PCWSTR = ::windows_sys::w!("WLDPCONFIGCI");
+pub const SRP_POLICY_WLDPCONFIGCI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WLDPCONFIGCI");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_WLDPMSI: ::windows_sys::core::PCWSTR = ::windows_sys::w!("WLDPMSI");
+pub const SRP_POLICY_WLDPMSI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WLDPMSI");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
-pub const SRP_POLICY_WLDPSCRIPT: ::windows_sys::core::PCWSTR = ::windows_sys::w!("WLDPSCRIPT");
+pub const SRP_POLICY_WLDPSCRIPT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WLDPSCRIPT");
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
 pub type SAFER_COMPUTE_TOKEN_FROM_LEVEL_FLAGS = u32;
 #[doc = "*Required features: `\"Win32_Security_AppLocker\"`*"]
